@@ -11,9 +11,9 @@ DAY_CHOICES = (
 BITWISE_DAY_CHOICES = (
     (1, "Sun","Sunday"),
     (2, "Mon","Monday"),
-    (4, "Tues","Tuesday"),
-    (8, "Weds","Wednesday"),
-    (16, "Thur","Thursday"),
+    (4, "Tue","Tuesday"),
+    (8, "Wed","Wednesday"),
+    (16, "Thu","Thursday"),
     (32, "Fri","Friday"),
     (64, "Sat","Saturday"),
 )
